v0.3.1 (2021-10-18)
===================

- Fix spec to properly find the tarball.

v0.3.0 (2020-10-12)
===================

- Download signature file.
- Fix build requires in spec file.
- Handle xml report file from build service.

v0.2.0 (2020-04-06)
===================

- Add disallow license and package options.

v0.1.2 (2020-03-17)
===================

- Handle new checksum format from build service.

v0.1.1 (2019-12-20)
===================

- Remove man pages from source.
- Use explicit regex match for kiwi version.
- Handle multiple digit versions with kiwi version.

v0.1.0 (2019-11-20)
===================

- Allow expressive image conditions similar to package conditions.

v0.0.4 (2019-10-24)
===================

- Remove usr dir from spec.
- Account for content after checksum.

v0.0.3 (2019-07-10)
===================

- Release matches version.

v0.0.2 (2019-07-10)
===================

- No changes

v0.0.1 (2019-07-10)
===================

- Initial release.
